databaseExpiredDuration property

  1. @protected
Duration? get databaseExpiredDuration
inherited

Common default field for putExpired, putExpiredTyped. Sets the expiration date for the database, will be automatically substituted into the query if a named argument is not specified. To use it, you need to override.

Implementation

@protected
Duration? get databaseExpiredDuration => null;